A static checking layer on top of printf. It hasn't
been tested much, but static argument checking is always a good idea. To use
it, add
{-# LANGUAGE TemplateHaskell #-}
import Text.Printf.Mauke.TH
at the top of your code and call $(printf "%d %d") x y instead of
printf "%d %d" x y.